Enum rustdds::dds::statusevents::DataReaderStatus [−][src]
Variants
Sample was rejected, because resource limits would have been exeeded.
Fields of SampleRejected
count: CountWithChangelast_reason: SampleRejectedStatusKindRemote Writer has become active or inactive.
Fields of LivelinessChanged
alive_total: CountWithChangenot_alive_total: CountWithChangeDeadline requested by this DataReader was missed.
Fields of RequestedDeadlineMissed
count: CountWithChangeThis DataReader has requested a QoS policy that is incompatibel with what is offered.
Fields of RequestedIncompatibleQos
A sample has been lost (never received). (Whtever this means?)
Fields of SampleLost
count: CountWithChangeThe DataReader has found a DataWriter that matches the Topic and has compatible QoS, or has ceased to be matched with a DataWriter that was previously considered to be matched.
Fields of SubscriptionMatched
total: CountWithChangecurrent: CountWithChangeTrait Implementations
impl Clone for DataReaderStatus[src]
fn clone(&self) -> DataReaderStatus[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Debug for DataReaderStatus[src]
impl<D, DA> StatusEvented<DataReaderStatus> for DataReader<D, DA> where
D: Keyed + DeserializeOwned,
DA: DeserializerAdapter<D>, [src]
D: Keyed + DeserializeOwned,
DA: DeserializerAdapter<D>,
fn as_status_evented(&mut self) -> &dyn Evented[src]
fn try_recv_status(&self) -> Option<DataReaderStatus>[src]