pub struct Presentation {
pub access_scope: PresentationAccessScope,
pub coherent_access: bool,
pub ordered_access: bool,
}Expand description
DDS 2.2.3.6 PRESENTATION
Fields
access_scope: PresentationAccessScopecoherent_access: boolordered_access: boolTrait Implementations
Sourceimpl Clone for Presentation
impl Clone for Presentation
Sourcefn clone(&self) -> Presentation
fn clone(&self) -> Presentation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Presentation
impl Debug for Presentation
Sourceimpl<'de> Deserialize<'de> for Presentation
impl<'de> Deserialize<'de> for Presentation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for Presentation
impl Hash for Presentation
Sourceimpl PartialEq for Presentation
impl PartialEq for Presentation
Sourceimpl<'a_, C_: Context> Readable<'a_, C_> for Presentation
impl<'a_, C_: Context> Readable<'a_, C_> for Presentation
fn read_from<R_: Reader<'a_, C_>>(_reader_: &mut R_) -> Result<Self, C_::Error>
fn minimum_bytes_needed() -> usize
Sourcefn read_from_buffer(buffer: &'a [u8]) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn read_from_buffer(buffer: &'a [u8]) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
Deserializes from a given buffer. Read more
Sourcefn read_with_length_from_buffer(
buffer: &'a [u8],
) -> (Result<Self, <C as Context>::Error>, usize)where
Self: DefaultContext<Context = C>,
C: Default,
fn read_with_length_from_buffer(
buffer: &'a [u8],
) -> (Result<Self, <C as Context>::Error>, usize)where
Self: DefaultContext<Context = C>,
C: Default,
Deserializes from a given buffer while also returning the amount of bytes consumed. Read more
Sourcefn read_from_buffer_copying_data(
buffer: &[u8],
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn read_from_buffer_copying_data(
buffer: &[u8],
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
Deserializes from a given buffer. Read more
Sourcefn read_with_length_from_buffer_copying_data(
buffer: &[u8],
) -> (Result<Self, <C as Context>::Error>, usize)where
Self: DefaultContext<Context = C>,
C: Default,
fn read_with_length_from_buffer_copying_data(
buffer: &[u8],
) -> (Result<Self, <C as Context>::Error>, usize)where
Self: DefaultContext<Context = C>,
C: Default,
Deserializes from a given buffer while also returning the amount of bytes consumed. Read more
Sourcefn read_from_stream_unbuffered(
stream: impl Read,
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn read_from_stream_unbuffered(
stream: impl Read,
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
Reads from a given stream without any buffering. Read more
Sourcefn read_from_stream_buffered(
stream: impl Read,
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn read_from_stream_buffered(
stream: impl Read,
) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
Reads from a given stream with internal buffering. Read more
fn read_from_file(path: impl AsRef<Path>) -> Result<Self, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn read_from_buffer_with_ctx( context: C, buffer: &'a [u8], ) -> Result<Self, <C as Context>::Error>
fn read_with_length_from_buffer_with_ctx( context: C, buffer: &'a [u8], ) -> (Result<Self, <C as Context>::Error>, usize)
fn read_from_buffer_copying_data_with_ctx( context: C, buffer: &[u8], ) -> Result<Self, <C as Context>::Error>
fn read_with_length_from_buffer_copying_data_with_ctx( context: C, buffer: &[u8], ) -> (Result<Self, <C as Context>::Error>, usize)
fn read_with_length_from_buffer_copying_data_with_ctx_mut( context: &mut C, buffer: &[u8], ) -> (Result<Self, <C as Context>::Error>, usize)
fn read_from_stream_unbuffered_with_ctx<S>(
context: C,
stream: S,
) -> Result<Self, <C as Context>::Error>where
S: Read,
fn read_from_stream_buffered_with_ctx<S>(
context: C,
stream: S,
) -> Result<Self, <C as Context>::Error>where
S: Read,
fn read_from_file_with_ctx( context: C, path: impl AsRef<Path>, ) -> Result<Self, <C as Context>::Error>
Sourceimpl Serialize for Presentation
impl Serialize for Presentation
Sourceimpl<C_: Context> Writable<C_> for Presentation
impl<C_: Context> Writable<C_> for Presentation
fn write_to<T_: ?Sized + Writer<C_>>( &self, _writer_: &mut T_, ) -> Result<(), C_::Error>
fn write_to_buffer(
&self,
buffer: &mut [u8],
) -> Result<(), <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn write_to_vec(&self) -> Result<Vec<u8>, <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn write_to_stream<S>(&self, stream: S) -> Result<(), <C as Context>::Error>
fn write_to_file(
&self,
path: impl AsRef<Path>,
) -> Result<(), <C as Context>::Error>where
Self: DefaultContext<Context = C>,
C: Default,
fn write_to_buffer_with_ctx( &self, context: C, buffer: &mut [u8], ) -> Result<(), <C as Context>::Error>
fn write_to_buffer_with_ctx_mut( &self, context: &mut C, buffer: &mut [u8], ) -> Result<(), <C as Context>::Error>
fn write_to_vec_with_ctx( &self, context: C, ) -> Result<Vec<u8>, <C as Context>::Error>
fn write_to_vec_with_ctx_mut( &self, context: &mut C, ) -> Result<Vec<u8>, <C as Context>::Error>
fn write_to_stream_with_ctx<S>(
&self,
context: C,
stream: S,
) -> Result<(), <C as Context>::Error>where
S: Write,
fn write_to_file_with_ctx( &self, context: C, path: impl AsRef<Path>, ) -> Result<(), <C as Context>::Error>
fn bytes_needed(&self) -> Result<usize, <C as Context>::Error>
impl Copy for Presentation
impl Eq for Presentation
impl StructuralPartialEq for Presentation