Module ros2

Module ros2 

👎Deprecated since 0.8.5:

Use crate ros2-client instead.

ROS2 interface using DDS module - DO NOT USE - Use ros2-client instead.

Modules

builtin_datatypesDeprecated
Some builtin datatypes needed for ROS2 communication
builtin_topicsDeprecated
Some convenience topic infos for ROS2 communication

Structs

NodeOptionsDeprecated
Configuration of RosNode
RosNodeDeprecated
Node in ROS2 network. Holds necessary readers and writers for rosout and parameter events topics internally. Should be constructed using builder.
RosParticipantDeprecated
RosParticipant sends and receives other participants information in ROS2 network

Type Aliases

KeyedRosPublisherDeprecated
KeyedRosPublisherCdrDeprecated
KeyedRosSubscriberDeprecated
KeyedRosSubscriberCdrDeprecated
RosPublisherDeprecated
RosPublisherCdrDeprecated
RosSubscriberDeprecated
RosSubscriberCdrDeprecated