pub struct WriteOptions { /* private fields */ }Expand description
Type to be used with write_with_options. Use WriteOptionsBuilder to construct this.
Implementations
Sourceimpl WriteOptions
impl WriteOptions
pub fn source_timestamp(&self) -> Option<Timestamp>
pub fn to_single_reader(&self) -> Option<GUID>
Sourcepub fn best_effort_may_block(&self) -> bool
pub fn best_effort_may_block(&self) -> bool
Whether a best-effort write call is allowed to block under send-socket
congestion (see WriteOptionsBuilder::best_effort_may_block).
Only meaningful for best-effort DataWriters; reliable writers always apply
back-pressure regardless of this flag. Defaults to false, so by default
a best-effort write never blocks and drops samples under congestion,
as required by DDS v1.4 section 2.2.2.4.2.11.