pub trait TopicDescription {
// Required methods
fn participant(&self) -> Option<DomainParticipant>;
fn get_type(&self) -> TypeDesc;
fn name(&self) -> String;
}Expand description
Trait approximation of DDS 2.2.2.3.1 TopicDescription Class
Now it is utterly useless, but if we ever add ContentFilteredTopic or MultiTopic, then it may turn out to be useful.
Required Methods
fn participant(&self) -> Option<DomainParticipant>
fn get_type(&self) -> TypeDesc
fn name(&self) -> String
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl TopicDescription for Topic
Implements some default topic interfaces functions defined in DDS spec